@@ -1,11 +1,10 @@
-// $Id: MultiLineStringTest.cpp 2162 2008-08-18 16:30:56Z mloskot $
+// $Id: MultiLineStringTest.cpp 2344 2009-04-09 21:46:30Z mloskot $
 // 
 // Test Suite for geos::geom::MultiLineString class.
 
+#include <tut.hpp>
 // geos
 #include <geos/geom/MultiLineString.h>
-// tut
-#include <tut.h>
 
 namespace tut
 {
